# estd

Extended standard library


## Install

```shell
pip install -I git+https://gitee.com/xhqsm/estd.git
```

## Usage

### Class

#### Thread

Thread with return value

### Decorator

#### logit

Decorator to log the execution time of a function

### Function

#### has_overlap

Check if a query region overlaps with any of the regions in the sorted regions dict
